@@ -9,7 +9,7 @@ package HTML::Parser;
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = "3.60";
+$VERSION = "3.62";
 
 require HTML::Entities;
 
@@ -240,13 +240,12 @@ to the C<HTML::Parser> object:
 
 =item $p->parse( $string )
 
-Parse $string as the next chunk of the HTML document.  The return
-value is normally a reference to the parser object (i.e. $p).
-Handlers invoked should not attempt to modify the $string in-place until
-$p->parse returns.
+Parse $string as the next chunk of the HTML document.  Handlers invoked should
+not attempt to modify the $string in-place until $p->parse returns.
 
-If an invoked event handler aborts parsing by calling $p->eof, then
-$p->parse() will return a FALSE value.
+If an invoked event handler aborts parsing by calling $p->eof, then $p->parse()
+will return a FALSE value.  Otherwise the return value is a reference to the
+parser object ($p).
 
 =item $p->parse( $code_ref )
 
@@ -690,7 +689,7 @@ The first column on a line is 0.
 Dtext causes the decoded text to be passed.  General entities are
 automatically decoded unless the event was inside a CDATA section or
 was between literal start and end tags (C<script>, C<style>,
-C<xmp>, C<iframe> and C<plaintext>).
+C<xmp>, C<iframe>, C<title>, C<textarea> and C<plaintext>).
 
 The Unicode character set is assumed for entity decoding.  With Perl
 version 5.6 or earlier only the Latin-1 range is supported, and
@@ -709,7 +708,7 @@ C<comment>, C<process>, C<start_document> or C<end_document>.
 
 Is_cdata causes a TRUE value to be passed if the event is inside a CDATA
 section or between literal start and end tags (C<script>,
-C<style>, C<xmp>, C<iframe> and C<plaintext>).
+C<style>, C<xmp>, C<iframe>, C<title>, C<textarea> and C<plaintext>).
 
 if the flag is FALSE for a text event, then you should normally
 either use C<dtext> or decode the entities yourself before the text is
